@@ -42,33 +42,67 @@ def consistent(parent, flow):
 
         if resource_id and level_is_equal and index_is_equal:
             publishedFlow['requirement'] = flow['requirement']
-            parent.update(obj_id=None, payload=publishedFlow).isOk()
+            parent.update(None, publishedFlow).isOk()
             return True
 
     return False
 
 
+def get_node_identity_pair(root_node):
+    key = 'alias' if 'alias' in root_node else 'displayName'
+    unique_identifier = root_node[key]
+
+    return [key, unique_identifier]
+
+def get_matching_flow_from_server(flow, stored_flows):
+    [_, flow_id] = get_node_identity_pair(flow)
+
+    for stored_flow in stored_flows:
+        [_, id] = get_node_identity_pair(stored_flow)
+        if flow_id == id:
+            return stored_flow
+
+    raise Exception("Trying to updated a built-in flow, with the wrong flow: " + flow + ". \n Make sure that this flow is defined in the built-in flow.")
+
+
+def merge_flows(flow_from_server = {}, local_flow={}):
+    changed = False
+    for key in local_flow.keys():
+        if key in flow_from_server and flow_from_server[key] != local_flow[key] and key != 'flowId':
+            flow_from_server[key] = local_flow[key]
+            changed = True
+
+    return [flow_from_server, changed]
+
 class AuthenticationFlowsImporter():
     def __init__(self, authentication_api):
         self.flowAPI = authentication_api
 
     def update(self, root_node, flows):
+        flow_api = self.flowAPI.flows(root_node)
+        executions_api = self.flowAPI.executions(root_node)
+
         if self.flowAPI.is_built_in(root_node):
+            stored_flows = flow_api.all()
+            #stored_executions = executions_api.all()
+
             for flow in flows:
                 if is_auth_flow(flow):
-                    self.flowAPI.flows(root_node).update(None, flow).isOk()
+                    flow_from_server = get_matching_flow_from_server(flow, stored_flows)
+                    [updated_flow, has_change] = merge_flows(flow_from_server, flow)
+
+                    if has_change:
+                        flow_api.update(None, updated_flow).isOk()
                 else:
-                    self.flowAPI.executions(root_node).update(None, flow).isOk()
+                    executions_api.update(None, flow).isOk()
         else:
             self.remove(root_node)
             self.flowAPI.create(root_node).isOk()
             self.publish(root_node, flows)
 
     def remove(self, root_node):
-        unique_identifier = root_node['alias'] if 'alias' in root_node else root_node['displayName']
-        key = 'alias' if 'alias' in root_node else 'displayName'
-
-        self.flowAPI.removeFirstByKV(key, unique_identifier)
+        [key, unique_identifier_value] = get_node_identity_pair(root_node)
+        self.flowAPI.removeFirstByKV(key, unique_identifier_value)
 
     def publish(self, root_node, flows):
         if not isinstance(flows, list):
