@@ -34,13 +34,15 @@ def elapsed_time(time2):
     return (time.time() - time2)
 
 class Token:
-    def __init__(self, well_known={}, payload=None, refresh_token=None, raw_json_str=None):
+    def __init__(self, well_known={}, payload=None, refresh_token=None, raw_json_str=None, client_id=None):
         self.token = None
         self.refresh_token = None
         self.expiring = 60
         self.well_known = well_known
         self.start_time = 0
         self.payload = None
+        self.client_id = client_id if client_id else "admin-cli"
+
 
         if payload:
             self.load_from_request_payload(payload)
@@ -66,18 +68,18 @@ class Token:
         self.start_time = time.time()
         self.payload = payload
 
+
     def expired(self):
-        if elapsed_time(self.start_time) >= (self.expiring - 10): # If current time is above expiring time minus 10 seconds we ask for a new token.
+        if elapsed_time(self.start_time) >= (self.expiring - 15): # If current time is above expiring time minus 10 seconds we ask for a new token.
             return True
 
         return False
 
-
     def refresh(self):
         token_endpoint = self.well_known['token_endpoint']
 
         body = {
-            "client_id": "admin-cli",
+            "client_id": self.client_id,
             "grant_type": "refresh_token",
             "refresh_token": self.refresh_token
         }
@@ -121,7 +123,7 @@ class OpenID:
 
 
     @staticmethod
-    def createAdminClient(username, password, url = None):
+    def createAdminClient(username=None, password=None, url = None):
         __props = {
             "client_id": "admin-cli",
             "grant_type": "password",
