@@ -1,5 +1,6 @@
 from .crud import KeycloakCRUD
 from .targets import Targets
+from .recovery import add_failiure_recovery_decorator
 
 def AuthenticationFlowURLBuilder(url):
     return Targets.makeWithURL(url).addResources(['flows'])
@@ -42,6 +43,7 @@ def choose_update_strategy(kc, root_node):
         return kc.update
 
 
+
 # The keycloak API is a bit crazy here they add with:
 # Post /parentId/executions/execution 
 # 
@@ -64,7 +66,6 @@ def build_action(kc, root_node, action_type):
 
     # Sadly the REST Endpoint to update executions components inside an authentication flow is somewhat broken.
     kc.update = choose_update_strategy(kc, root_node)
-
     return kc
 
 
@@ -77,7 +78,7 @@ class AuthenticationFlows(KeycloakCRUD):
         flow = KeycloakCRUD()
         flow.token = token
         flow.targets = targets.copy()
-        return flow
+        return add_failiure_recovery_decorator(flow)
 
     def is_built_in(self, root_node):
         return is_flow_built_in(root_node)
