@@ -3,12 +3,12 @@ from .resp import ResponseHandler
 
 class KeycloakCRUD(object):
     @staticmethod
-    def get_child(that, client_id, resource_name):
+    def get_child(that, resource_id, resource_name):
         kc = KeycloakCRUD()
         kc.token = that.token
         kc.targets = that.targets.copy()
 
-        kc.targets.addResources([client_id, resource_name])
+        kc.targets.addResources([resource_id, resource_name])
 
         return kc
 
@@ -61,7 +61,7 @@ class KeycloakCRUD(object):
         ret = requests.get(url, headers=self.headers())
         return ResponseHandler(url, method='Get').handleResponse(ret)
 
-    def findFirst(self, params): 
+    def findFirst(self, params):
         return self.findFirstByKV(params['key'], params['value'])
 
     def findFirstByKV(self, key, value):
@@ -101,4 +101,7 @@ class KeycloakCRUD(object):
     def exist(self, _id):
         return self.get(_id).ok()
 
+    def root(self):
+        return self.targets.targets['root']
+
 
