@@ -38,8 +38,12 @@ class GroupAndRolesMappingBuilder():
 
     def __fetchRoles(self, roles): 
         find = self.roles.findFirstByKV
-        return list( map(lambda name: find('name', name), roles) )
+        list_of_roles = list( map(lambda name: find('name', name), roles) )
+        for role in list_of_roles:
+            if not role:
+                raise Exception("One or more roles from the provided list: "+str(roles)+" do not exist.")
 
+        return list_of_roles
     def add(self, roles): 
         populatedListOfRoles = self.__fetchRoles(roles)
         return self.rolesMappings.create(populatedListOfRoles)
@@ -54,7 +58,7 @@ class GroupAndRolesMappingBuilder():
         ret = requests.delete(remove_target, data=json.dumps(populatedListOfRoles), headers=headers )
         return ResponseHandler(remove_target).handleResponse(ret)
 
-class Groups(KeycloakCRUD): 
+class Groups(KeycloakCRUD):
     def realmRoles(self, group):
         return GroupAndRolesMappingBuilder().build(group, self)
 
