@@ -239,6 +239,30 @@ class TestingAuthenticationFlowsAPI(unittest.TestCase):
         publisher.update(reset_credentials_flow, reset_credentials_flow_payload)
         execs2 = self.authenticationFlow.executions(reset_credentials_flow).all()
 
+
+    def testing_performing_updates_on_built_in_authentication_flows(self):
+        publisher = AuthenticationFlowsImporter(self.authenticationFlow)
+
+        clients_flow = {
+            "alias": "registration"
+        }
+
+        executors = load_sample('./test/payloads/executors/executor_3.json')
+
+        options = ['DISABLED', 'DISABLED', 'REQUIRED', 'DISABLED']
+        attempts = 6
+
+        while attempts > 0:
+            opt = options.pop(0)
+            executors[0]['requirement'] = opt
+            publisher.update(clients_flow, executors)
+            execs = self.authenticationFlow.executions(clients_flow).all()
+
+            self.assertEqual(execs[0]['requirement'], opt, "should be equals to -> " + opt)
+            self.assertEqual(execs[3]['requirement'], 'REQUIRED')
+            options.append(opt)
+            attempts = attempts - 1
+
     def testing_performing_authentication_flows_updates(self):
         publisher = AuthenticationFlowsImporter(self.authenticationFlow)
 
@@ -262,9 +286,8 @@ class TestingAuthenticationFlowsAPI(unittest.TestCase):
     @classmethod
     def setUpClass(self):
         self.testbed = TestBed()
+        self.testbed.deleteRealms()
         self.testbed.createRealms()
-        self.testbed.createUsers()
-        self.testbed.createClients()
         self.authenticationFlow = self.testbed.getKeycloak().build('authentication', self.testbed.REALM)
 
         basic_flow = {
@@ -328,7 +351,7 @@ class TestingAuthenticationFlowsAPI(unittest.TestCase):
 
     @classmethod
     def tearDownClass(self):
-        # self.testbed.goodBye()
+        self.testbed.goodBye()
         return True
 
 
