@@ -23,10 +23,11 @@ class TestingUserAPI(unittest.TestCase):
         state2 = idp1.create(oid).isOk()
         self.assertTrue(state2)
 
-        resources = idp1.all()
+        oidc_ip = idp1.findFirstByKV('alias', 'oidc666')
+        saml_ip = idp1.findFirstByKV('alias', 'saml666')
 
-        self.assertEqual(resources[0]['alias'], saml['alias'], 'SAML alias should match')
-        self.assertEqual(resources[1]['alias'], oid['alias'], 'SAML alias should match')
+        self.assertEqual(saml_ip['alias'], saml['alias'], 'SAML alias should match')
+        self.assertEqual(oidc_ip['alias'], oid['alias'], 'SAML alias should match')
 
     @classmethod
     def setUpClass(self):
@@ -39,7 +40,7 @@ class TestingUserAPI(unittest.TestCase):
 
     @classmethod
     def tearDownClass(self):
-        # self.testbed.goodBye()
+        self.testbed.goodBye()
         return True
 
 
